Documentation
¶
Overview ¶
Package pod provides Registry interface and it's RESTStorage implementation for storing Pod api objects.
Index ¶
- type REST
- func (rs *REST) Create(obj runtime.Object) (<-chan runtime.Object, error)
- func (rs *REST) Delete(id string) (<-chan runtime.Object, error)
- func (rs *REST) Get(id string) (runtime.Object, error)
- func (rs *REST) List(selector labels.Selector) (runtime.Object, error)
- func (*REST) New() runtime.Object
- func (rs *REST) Update(obj runtime.Object) (<-chan runtime.Object, error)
- func (rs *REST) Watch(label, field labels.Selector, resourceVersion uint64) (watch.Interface, error)
- type RESTConfig
- type Registry
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type REST ¶
type REST struct {
// contains filtered or unexported fields
}
REST implements the RESTStorage interface in terms of a PodRegistry.
type RESTConfig ¶
type RESTConfig struct {
CloudProvider cloudprovider.Interface
PodCache client.PodInfoGetter
PodInfoGetter client.PodInfoGetter
Registry Registry
}
type Registry ¶
type Registry interface {
// ListPods obtains a list of pods that match selector.
ListPods(selector labels.Selector) (*api.PodList, error)
// Watch for new/changed/deleted pods
WatchPods(resourceVersion uint64, filter func(*api.Pod) bool) (watch.Interface, error)
// Get a specific pod
GetPod(podID string) (*api.Pod, error)
// Create a pod based on a specification.
CreatePod(pod *api.Pod) error
// Update an existing pod
UpdatePod(pod *api.Pod) error
// Delete an existing pod
DeletePod(podID string) error
}
Registry is an interface implemented by things that know how to store Pod objects.
Click to show internal directories.
Click to hide internal directories.