Documentation
¶
Overview ¶
Package service provides Registry interface and it's RESTStorage implementation for storing Service api objects.
Index ¶
- func GetServiceEnvironmentVariables(registry Registry, machine string) ([]api.EnvVar, error)
- type REST
- func (rs *REST) Create(obj runtime.Object) (<-chan runtime.Object, error)
- func (rs *REST) Delete(id string) (<-chan runtime.Object, error)
- func (rs *REST) Get(id string) (runtime.Object, error)
- func (rs *REST) List(selector labels.Selector) (runtime.Object, error)
- func (*REST) New() runtime.Object
- func (rs *REST) ResourceLocation(id string) (string, error)
- func (rs *REST) Update(obj runtime.Object) (<-chan runtime.Object, error)
- func (rs *REST) Watch(label, field labels.Selector, resourceVersion uint64) (watch.Interface, error)
- type Registry
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type REST ¶
type REST struct {
// contains filtered or unexported fields
}
REST adapts a service registry into apiserver's RESTStorage model.
func (*REST) ResourceLocation ¶
ResourceLocation returns a URL to which one can send traffic for the specified service.
type Registry ¶
type Registry interface {
ListServices() (*api.ServiceList, error)
CreateService(svc *api.Service) error
GetService(name string) (*api.Service, error)
DeleteService(name string) error
UpdateService(svc *api.Service) error
WatchServices(labels, fields labels.Selector, resourceVersion uint64) (watch.Interface, error)
// TODO: endpoints and their implementation should be separated, setting endpoints should be
// supported via the API, and the endpoints-controller should use the API to update endpoints.
endpoint.Registry
}
Registry is an interface for things that know how to store services.
Click to show internal directories.
Click to hide internal directories.